package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Config;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.HostMapper;
import com.datacloudsec.scan.service.IConfig;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IHost;
import com.datacloudsec.scan.service.ISystem;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.PeriodTask;
import com.datacloudsec.scan.tasks.scheduler.job.SynTimeJob;
import com.datacloudsec.scan.tasks.scheduler.time.TimeInterval;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.ProjectUtil;
import com.datacloudsec.utils.RuntimeUtil;
import com.datacloudsec.utils.SecretUtil;
import com.datacloudsec.utils.VersionUtil;
import com.datacloudsec.utils.ZipUtil;
import com.howie.hlicense.info.LicenseLic;
import java.io.BufferedReader;
import java.io.File;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URLEncoder;
import java.nio.charset.Charset;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.servlet.http.HttpSession;
import org.apache.commons.codec.binary.Hex;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/SystemService.class */
public class SystemService implements ISystem {
    private HostMapper host = (HostMapper) InstanceUtil.newDaoInstance(HostMapper.class);
    private IConfig config = (IConfig) InstanceUtil.newServiceInstance(ConfigService.class);
    private IEngine engineService = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);
    private EngineMapper engineMapper = (EngineMapper) InstanceUtil.newDaoInstance(EngineMapper.class);

    public void restore() throws Exception {
        Set<String> rebootIp = new HashSet<>();
        String licCmp = (String) InitSystemTask.licenseApp.getLicenseLic().getParams().get("cmp");
        List<Integer> notType = new ArrayList<>();
        if (!licCmp.contains("webscan")) {
            notType.add(3);
        }
        if (!licCmp.contains("sysscan")) {
            notType.add(5);
        }
        if (!licCmp.contains("bline")) {
            notType.add(6);
        }
        if (!licCmp.contains("pwd")) {
            notType.add(4);
        }
        if (!licCmp.contains("devfind")) {
            notType.add(1);
        }
        if (!licCmp.contains("wifi")) {
            notType.add(11);
        }
        IEngine engine = new EngineService();
        for (Map<String, Object> h : this.host.search(notType.size() == 0 ? null : StringUtils.join(notType, ","))) {
            String ip = ObjectUtil.getString(h.get("ip"), "");
            int port = ObjectUtil.getInt(h.get("port"), 0);
            switch (ObjectUtil.getInt(h.get("type"), 0)) {
                case 0:
                    rebootIp.add(ip);
                    break;
                case 1:
                    engine.sniffingRestore(ip, port);
                    rebootIp.add(ip);
                    break;
                case 3:
                    engine.webRestore(ip, port);
                    rebootIp.add(ip);
                    break;
                case 5:
                    engine.sysRestore(ip, port);
                    rebootIp.add(ip);
                    break;
                case 6:
                    engine.blineRestore(ip, port);
                    rebootIp.add(ip);
                    break;
                case 11:
                    rebootIp.add(ip);
                    break;
            }
        }
        emptyDir(Constant.COMMON_DIR);
        emptyDir(Constant.TEMP_DIR);
        byte[] content = FileUtils.readFileToByteArray(new File(Constant.WORK_DIR, "conf/SqlMapConfig.xml"));
        try {
            SecretUtil.decryptEncrypt("aes", content, "anshuyun123SEF@#".getBytes());
        } catch (Exception e) {
            LOG.error("解密配置文件出错，可能是未加密");
        }
        Map<String, String> dbConf = MybatisUtil.getDbConf();
        String url = "jdbc:mysql://" + dbConf.get("mysqlServer") + ":" + dbConf.get("mysqlPort") + "?useUnicode=true&amp;characterEncoding=UTF-8&amp;connectTimeout=3000&amp;zeroDateTimeBehavior=convertToNull&amp;rewriteBatchedStatements=true&amp;autoReconnect=true&amp;failOverReadOnly=false";
        String username = dbConf.get("mysqlUser");
        String password = dbConf.get("mysqlPassword");
        Statement sta1 = null;
        Statement sta2 = null;
        try {
            Connection con = DriverManager.getConnection(url, username, password);
            sta1 = con.createStatement();
            sta1.executeUpdate("drop database if exists " + Config.getInstance().getString("mysql-dbname", "scan"));
            sta2 = con.createStatement();
            sta2.executeUpdate("create database if not exists " + Config.getInstance().getString("mysql-dbname", "scan"));
            if (sta1 != null) {
                sta1.close();
            }
            if (sta2 != null) {
                sta2.close();
            }
            Iterator<String> it = rebootIp.iterator();
            while (it.hasNext()) {
                try {
                    engine.hostOper(it.next(), true);
                } catch (Exception e2) {
                    LOG.error("", e2);
                }
            }
        } catch (Throwable th) {
            if (sta1 != null) {
                sta1.close();
            }
            if (sta2 != null) {
                sta2.close();
            }
            throw th;
        }
    }

    /* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/SystemService$CmdInfo.class */
    private static class CmdInfo {
        private String key;
        private boolean finish;
        private String error;

        public String getKey() {
            return this.key;
        }

        public boolean isFinish() {
            return this.finish;
        }

        public String getError() {
            return this.error;
        }

        public void setKey(String key) {
            this.key = key;
        }

        public void setFinish(boolean finish) {
            this.finish = finish;
        }

        public void setError(String error) {
            this.error = error;
        }

        public boolean equals(Object o) {
            if (o == this) {
                return true;
            }
            if (!(o instanceof CmdInfo)) {
                return false;
            }
            CmdInfo other = (CmdInfo) o;
            if (!other.canEqual(this)) {
                return false;
            }
            Object this$key = getKey();
            Object other$key = other.getKey();
            if (this$key == null) {
                if (other$key != null) {
                    return false;
                }
            } else if (!this$key.equals(other$key)) {
                return false;
            }
            if (isFinish() != other.isFinish()) {
                return false;
            }
            Object this$error = getError();
            Object other$error = other.getError();
            return this$error == null ? other$error == null : this$error.equals(other$error);
        }

        protected boolean canEqual(Object other) {
            return other instanceof CmdInfo;
        }

        public int hashCode() {
            Object $key = getKey();
            int result = (1 * 59) + ($key == null ? 0 : $key.hashCode());
            int result2 = (result * 59) + (isFinish() ? 79 : 97);
            Object $error = getError();
            return (result2 * 59) + ($error == null ? 0 : $error.hashCode());
        }

        public String toString() {
            return "SystemService.CmdInfo(key=" + getKey() + ", finish=" + isFinish() + ", error=" + getError() + ")";
        }
    }

    /* JADX WARN: Type inference failed for: r0v62, types: [com.datacloudsec.scan.service.impl.SystemService$1] */
    public void execToolsCmd(final HttpSession session, String host, final Integer cmd, String param) throws Exception {
        String host2 = StringUtils.replaceEach(host, new String[]{"$", "(", ")", "`", "&", "|", "\"", "'"}, new String[]{"", "", "", "", "", "", "", ""});
        final String key = String.valueOf(session.getId()) + cmd;
        session.removeAttribute(key);
        session.removeAttribute(String.valueOf(key) + "error");
        session.removeAttribute(String.valueOf(key) + "finish");
        Map<String, String> curlParam = new HashMap<>();
        curlParam.put(ReportService.REPORT_STATE_READY, "-v");
        curlParam.put(ReportService.REPORT_STATE_SUCCESS, "-k");
        curlParam.put(ReportService.REPORT_STATE_FAILED, "--location");
        List<String> cmdList = new ArrayList<>();
        if (System.getProperty("os.name").toLowerCase().contains("window")) {
            cmdList.add("cmd");
            cmdList.add("/c");
            if (cmd.intValue() != 1) {
                if (cmd.intValue() == 2) {
                    throw new UEException("Windows系统不支持curl命令");
                }
                if (cmd.intValue() == 3) {
                    throw new UEException("Windows系统不支持traceroute命令");
                }
                if (cmd.intValue() == 5) {
                    throw new UEException("Windows系统不支持route命令");
                }
                throw new UEException("不支持该命令");
            }
            cmdList.add("ping");
            cmdList.add("\"" + host2 + "\"");
        } else {
            cmdList.add("/bin/sh");
            cmdList.add("-c");
            if (cmd.intValue() == 1) {
                cmdList.add(String.valueOf(host2.contains(":") ? "ping6" : "ping") + " -c 4 \"" + host2 + "\"");
            } else if (cmd.intValue() == 2) {
                StringBuffer buf = new StringBuffer();
                if (param != null) {
                    for (String s : param.split(",")) {
                        String v = ObjectUtil.getString(curlParam.get(s), (String) null);
                        if (v != null) {
                            buf.append(" " + v);
                        }
                    }
                }
                cmdList.add("curl \"" + host2 + "\" -g" + buf.toString());
            } else if (cmd.intValue() == 3) {
                cmdList.add("traceroute -m 15 \"" + host2 + "\"");
            } else if (cmd.intValue() == 5) {
                cmdList.add("route -n");
            } else {
                throw new UEException("不支持该命令");
            }
        }
        LOG.debug("执行命令：" + StringUtils.join(cmdList, ","));
        ProcessBuilder pb = new ProcessBuilder(cmdList);
        pb.redirectErrorStream(true);
        final Process process = pb.start();
        new Thread() { // from class: com.datacloudsec.scan.service.impl.SystemService.1
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                BufferedReader br = null;
                InputStreamReader isr = null;
                InputStream is = null;
                try {
                    try {
                        is = process.getInputStream();
                        isr = new InputStreamReader(is, cmd.intValue() == 2 ? "UTF8" : Charset.defaultCharset().toString());
                        br = new BufferedReader(isr);
                        while (true) {
                            String line = br.readLine();
                            if (line == null) {
                                break;
                            } else {
                                session.setAttribute(key, String.valueOf(ObjectUtil.getString(session.getAttribute(key), "")) + "\r\n" + line);
                            }
                        }
                        session.setAttribute(String.valueOf(key) + "finish", true);
                        IOUtils.closeQuietly(br);
                        IOUtils.closeQuietly(isr);
                        IOUtils.closeQuietly(is);
                        if (process != null) {
                            process.destroy();
                        }
                    } catch (Exception e) {
                        session.setAttribute(String.valueOf(key) + "error", "读取运行结果出错");
                        SystemService.LOG.error("命令运行出错", e);
                        session.setAttribute(String.valueOf(key) + "finish", true);
                        IOUtils.closeQuietly(br);
                        IOUtils.closeQuietly(isr);
                        IOUtils.closeQuietly(is);
                        if (process != null) {
                            process.destroy();
                        }
                    }
                } catch (Throwable th) {
                    session.setAttribute(String.valueOf(key) + "finish", true);
                    IOUtils.closeQuietly(br);
                    IOUtils.closeQuietly(isr);
                    IOUtils.closeQuietly(is);
                    if (process != null) {
                        process.destroy();
                    }
                    throw th;
                }
            }
        }.start();
    }

    /* JADX WARN: Removed duplicated region for block: B:24:0x0059 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public boolean getSnmp() throws java.lang.Exception {
        /*
            r6 = this;
            r0 = 0
            r7 = r0
            java.lang.Runtime r0 = java.lang.Runtime.getRuntime()     // Catch: java.lang.Throwable -> L65
            r1 = 3
            java.lang.String[] r1 = new java.lang.String[r1]     // Catch: java.lang.Throwable -> L65
            r2 = r1
            r3 = 0
            java.lang.String r4 = "/bin/sh"
            r2[r3] = r4     // Catch: java.lang.Throwable -> L65
            r2 = r1
            r3 = 1
            java.lang.String r4 = "-c"
            r2[r3] = r4     // Catch: java.lang.Throwable -> L65
            r2 = r1
            r3 = 2
            java.lang.String r4 = "systemctl is-enabled snmpd.service"
            r2[r3] = r4     // Catch: java.lang.Throwable -> L65
            java.lang.Process r0 = r0.exec(r1)     // Catch: java.lang.Throwable -> L65
            r7 = r0
            r0 = r7
            int r0 = r0.waitFor()     // Catch: java.lang.Throwable -> L65
            if (r0 == 0) goto L35
            r0 = r7
            if (r0 == 0) goto L33
            r0 = r7
            r0.destroy()     // Catch: java.lang.Exception -> L31
            goto L33
        L31:
            r11 = move-exception
        L33:
            r0 = 0
            return r0
        L35:
            r0 = r7
            java.io.InputStream r0 = r0.getInputStream()     // Catch: java.lang.Throwable -> L65
            java.lang.String r0 = org.apache.commons.io.IOUtils.toString(r0)     // Catch: java.lang.Throwable -> L65
            r8 = r0
            r0 = r8
            if (r0 == 0) goto L52
            r0 = r8
            java.lang.String r0 = r0.toLowerCase()     // Catch: java.lang.Throwable -> L65
            java.lang.String r1 = "enabled"
            boolean r0 = r0.contains(r1)     // Catch: java.lang.Throwable -> L65
            if (r0 == 0) goto L52
            r0 = 1
            goto L53
        L52:
            r0 = 0
        L53:
            r10 = r0
            r0 = r7
            if (r0 == 0) goto L62
            r0 = r7
            r0.destroy()     // Catch: java.lang.Exception -> L60
            goto L62
        L60:
            r11 = move-exception
        L62:
            r0 = r10
            return r0
        L65:
            r9 = move-exception
            r0 = r7
            if (r0 == 0) goto L73
            r0 = r7
            r0.destroy()     // Catch: java.lang.Exception -> L71
            goto L73
        L71:
            r11 = move-exception
        L73:
            r0 = r9
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.datacloudsec.scan.service.impl.SystemService.getSnmp():boolean");
    }

    public boolean setSnmp(boolean checked) throws Exception {
        String[] cmd;
        String[] cmd2;
        if (checked) {
            cmd = new String[]{"/bin/sh", "-c", "sudo systemctl enable snmpd.service"};
            cmd2 = new String[]{"/bin/sh", "-c", "sudo systemctl start snmpd.service"};
        } else {
            cmd = new String[]{"/bin/sh", "-c", "sudo systemctl stop snmpd.service"};
            cmd2 = new String[]{"/bin/sh", "-c", "sudo systemctl disable snmpd.service"};
        }
        Process process = null;
        try {
            Process process2 = Runtime.getRuntime().exec(cmd);
            if (process2.waitFor() != 0) {
                if (process2 == null) {
                    return false;
                }
                try {
                    process2.destroy();
                    return false;
                } catch (Exception e) {
                    return false;
                }
            }
            process = Runtime.getRuntime().exec(cmd2);
            if (process.waitFor() != 0) {
                if (process == null) {
                    return false;
                }
                try {
                    process.destroy();
                    return false;
                } catch (Exception e2) {
                    return false;
                }
            }
            if (process == null) {
                return true;
            }
            try {
                process.destroy();
                return true;
            } catch (Exception e3) {
                return true;
            }
        } catch (Throwable th) {
            if (process != null) {
                try {
                    process.destroy();
                } catch (Exception e4) {
                }
            }
            throw th;
        }
    }

    public void setTime(String time, Integer type, String server, Integer interval) throws Exception {
        String[] cmd;
        if (type.intValue() == 1) {
            if (StringUtils.isBlank(server) || interval == null) {
                throw new UEException("参数错误");
            }
            cmd = new String[]{"/bin/sh", "-c", "sudo ntpdate -u '" + server + "'"};
        } else {
            if (StringUtils.isBlank(time)) {
                throw new UEException("参数错误");
            }
            cmd = new String[]{"/bin/sh", "-c", "sudo date -s '" + time + "'"};
        }
        Process pro = Runtime.getRuntime().exec(cmd);
        try {
            pro.waitFor();
            String encoding = Charset.defaultCharset().toString();
            String error = IOUtils.toString(pro.getErrorStream(), encoding);
            if (StringUtils.isNotBlank(error)) {
                throw new UEException(error);
            }
            PeriodTask.getInstance().removeJob("ntptime_sync");
            this.config.setValue("time_type", new StringBuilder().append(type).toString());
            this.config.setValue("time_server", server);
            this.config.setValue("time_interval", interval == null ? "300" : new StringBuilder().append(interval).toString());
            if (type.intValue() == 1) {
                Map<String, Object> param = new HashMap<>();
                param.put("server", server);
                PeriodTask.getInstance().addJob(SynTimeJob.class, new TimeInterval(interval.intValue() * 60), "ntptime_sync", param);
            }
        } finally {
            pro.destroy();
        }
    }

    private void emptyDir(File dir) {
        if (dir != null && dir.isDirectory()) {
            for (File f : dir.listFiles()) {
                try {
                    if (f.isFile()) {
                        f.delete();
                    } else if (f.isDirectory()) {
                        FileUtils.deleteDirectory(f);
                    }
                } catch (Exception e) {
                    LOG.error("清空目录出错", e);
                }
            }
        }
    }

    public String encode(String enContent, String type, String key, String symmetryType) throws Exception {
        String result = "";
        if ("aes".equals(type) || "des".equals(type)) {
            byte[] b = SecretUtil.symmetryEncrypt(type, enContent.getBytes(), key.getBytes());
            if ("byte".equals(symmetryType)) {
                result = Hex.encodeHexString(b);
            } else {
                result = new BASE64Encoder().encode(b);
            }
        } else if (type.contains("sha-") || type.contains("md5")) {
            result = SecretUtil.digestSha1(enContent, type);
        } else if (type.contains("Hmac")) {
            result = SecretUtil.encryptHMAC(type, enContent.getBytes(), key.getBytes());
        } else if ("base64".equals(type)) {
            result = new BASE64Encoder().encode(enContent.getBytes());
        } else if ("hex".equals(type)) {
            result = Hex.encodeHexString(enContent.getBytes());
        } else if ("url".equals(type)) {
            result = URLEncoder.encode(enContent, "UTF-8");
        } else if ("rc4".equals(type)) {
            if (StringUtils.isBlank(key)) {
                return "";
            }
            byte[] b2 = SecretUtil.rc4Base(enContent.getBytes(), key);
            if ("byte".equals(symmetryType)) {
                result = Hex.encodeHexString(b2);
            } else {
                result = new BASE64Encoder().encode(b2);
            }
        }
        return result;
    }

    public String decode(String deContent, String type, String key, String symmetryType) throws Exception {
        byte[] b;
        byte[] b2;
        String result = "";
        if ("aes".equals(type) || "des".equals(type)) {
            if ("byte".equals(symmetryType)) {
                b = SecretUtil.decryptEncrypt(type, Hex.decodeHex(deContent.toCharArray()), key.getBytes());
            } else {
                b = SecretUtil.decryptEncrypt(type, new BASE64Decoder().decodeBuffer(deContent), key.getBytes());
            }
            result = new String(b, "UTF-8");
        } else if ("base64".equals(type)) {
            result = new String(new BASE64Decoder().decodeBuffer(deContent), "UTF-8");
        } else if ("hex".equals(type)) {
            result = new String(Hex.decodeHex(deContent.toCharArray()), "UTF-8");
        } else if ("rc4".equals(type)) {
            if (StringUtils.isBlank(key)) {
                return "";
            }
            if ("byte".equals(symmetryType)) {
                b2 = SecretUtil.rc4Base(Hex.decodeHex(deContent.toCharArray()), key);
            } else {
                b2 = SecretUtil.rc4Base(new BASE64Decoder().decodeBuffer(deContent), key);
            }
            result = new String(b2, "UTF-8");
        }
        return result;
    }

    private void offUpds(File file, List<Map<String, Object>> cmps) throws Exception {
        if (file != null && file.exists()) {
            LinkedList<File> list = new LinkedList<>();
            File[] files = file.listFiles();
            for (File file2 : files) {
                if (file2.isDirectory()) {
                    list.add(file2);
                } else {
                    try {
                        cmps.add(validePackage(file2));
                    } catch (Exception e) {
                        LOG.error("", e);
                    }
                }
            }
            while (!list.isEmpty()) {
                File temp_file = list.removeFirst();
                File[] files2 = temp_file.listFiles();
                for (File file22 : files2) {
                    if (file22.isDirectory()) {
                        list.add(file22);
                    } else {
                        try {
                            cmps.add(validePackage(file22));
                        } catch (Exception e2) {
                            LOG.error("", e2);
                        }
                    }
                }
            }
            return;
        }
        throw new UEException("文件不存在");
    }

    private Map<String, Object> validePackage(File f) throws Exception {
        String version;
        Map<String, Object> result = new HashMap<>();
        result.put("updpath", f.getPath());
        result.put("size", ObjectUtil.sizeToStr(f.length()));
        File zipFile = null;
        try {
            try {
                zipFile = ZipUtil.unZip(f, new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString()), "+_)(*&^%$#@!~asy");
                SAXReader reader = new SAXReader();
                Document document = reader.read(new File(zipFile, "conf.xml"));
                Element root = document.getRootElement();
                String number = ObjectUtil.getString(root.element("number").getTextTrim(), "");
                if (!IHost.NUMBER_TYPE.containsKey(number)) {
                    throw new UEException("此升级包不属于该产品！");
                }
                LicenseLic lic = InitSystemTask.licenseApp.getLicenseLic();
                if (lic.getMainTime() < System.currentTimeMillis()) {
                    throw new UEException("系统维保期已过，系统将不能享受维保，请及时联系厂商！");
                }
                Integer ecount = this.engineService.getEngCountByType((Integer) IHost.NUMBER_TYPE.get(number));
                if ((ecount == null || ecount.intValue() == 0) && !"asy0001-999".equals(number)) {
                    throw new UEException("无对应的引擎！");
                }
                result.put("type", IHost.NUMBER_TYPE.get(number));
                Element verEle = root.element("version");
                if (verEle == null) {
                    throw new UEException("版本号不存在！");
                }
                String newVersion = ObjectUtil.getString(verEle.getTextTrim(), "");
                if ("".equals(newVersion)) {
                    throw new UEException("版本号不存在！");
                }
                if ("asy0001-999".equals(number)) {
                    version = this.engineService.getPversion();
                } else if ("asy0001-015".equals(number)) {
                    version = Config.getInstance().getString("version", "");
                } else {
                    List<Map<String, Object>> list = this.engineService.getEngineByType((Integer) IHost.NUMBER_TYPE.get(number));
                    if (list == null || list.size() == 0) {
                        throw new UEException("引擎不存在！");
                    }
                    Map<String, Object> engine = list.get(0);
                    version = ObjectUtil.getString(engine.get("version"), "");
                }
                if (!VersionUtil.isNewVersion(version, newVersion)) {
                    throw new UEException("当前升级版本（V" + newVersion + "）为旧版本，请联系管理员获取最新升级包或选择在线升级！");
                }
                result.put("currver", version);
                result.put("version", newVersion);
                Element updatelist = root.element("updateList");
                if (updatelist != null) {
                    StringBuilder desct = new StringBuilder();
                    List<Element> elelist = updatelist.elements();
                    for (Element e : elelist) {
                        desct.append(e.getTextTrim()).append("|");
                    }
                    result.put("desct", (desct == null || desct.length() <= 0) ? desct : desct.substring(0, desct.length() - 1));
                }
                Element policyList = root.element("policyList");
                if (policyList != null) {
                    StringBuilder policyStr = new StringBuilder();
                    List<Element> elelist2 = policyList.elements();
                    for (Element e2 : elelist2) {
                        policyStr.append(e2.getTextTrim()).append("|");
                    }
                    result.put("policyList", (policyStr == null || policyStr.length() <= 0) ? policyStr : policyStr.substring(0, policyStr.length() - 1));
                }
                if (zipFile != null) {
                    FileUtils.deleteDirectory(zipFile);
                }
                return result;
            } catch (Exception e3) {
                throw new UEException("文件格式错误");
            }
        } catch (Throwable th) {
            if (zipFile != null) {
                FileUtils.deleteDirectory(zipFile);
            }
            throw th;
        }
    }

    public List<Map<String, Object>> upgradeOfflinePackage(File f) throws Exception {
        List<Map<String, Object>> cmps = new ArrayList<>();
        if (f.getName().toLowerCase().endsWith(".zip")) {
            File zipFile = ZipUtil.unZip(f, new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString()), "+_)(*&^%$#@!~asy");
            offUpds(zipFile, cmps);
        } else {
            cmps.add(validePackage(f));
        }
        if (cmps == null || cmps.size() == 0) {
            throw new UEException("当前版本为最新版本");
        }
        return cmps;
    }

    public void onlineUpload(String upd) throws Exception {
        if (StringUtils.isBlank(upd)) {
            throw new UEException("参数错误");
        }
        List<Map<String, Object>> updList = (List) JsonUtil.MAPPER.readValue(upd, List.class);
        Collections.sort(updList, new Comparator<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.SystemService.2
            @Override // java.util.Comparator
            public int compare(Map<String, Object> a, Map<String, Object> b) {
                return ObjectUtil.getInt(a.get("type")).compareTo(ObjectUtil.getInt(b.get("type")));
            }
        });
        Iterator<Map<String, Object>> it = updList.iterator();
        while (it.hasNext()) {
            Map<String, Object> updMap = it.next();
            String version = ObjectUtil.getString(updMap.get("version"), "");
            String currver = ObjectUtil.getString(updMap.get("currver"), "");
            Integer tint = ObjectUtil.getInt(updMap.get("type"));
            if (tint != null) {
                File f = null;
                try {
                    try {
                        f = this.engineService.downLoadFile("http://www.datacloudsec.com/upgrade/get-scan.html?type=" + tint, String.valueOf(System.nanoTime()) + ".update", Constant.TEMP_DIR.getPath());
                        if (tint.intValue() == 0) {
                            upgrade(f);
                        } else {
                            this.engineService.sendUpgrade(tint, f);
                        }
                    } catch (Exception e) {
                        if (f != null && f.exists()) {
                            f.delete();
                        }
                        LOG.error("", e);
                        throw e;
                    }
                } finally {
                    this.engineMapper.addUpgrade(Integer.valueOf(1), tint, currver, version, ObjectUtil.getString(updMap.get("content"), ""), ObjectUtil.getString(updMap.get("policyList"), ""));
                }
            }
        }
        System.exit(0);
    }

    public List<Map<String, Object>> checkUpdate() throws Exception {
        LicenseLic lic = InitSystemTask.licenseApp.getLicenseLic();
        if (lic.getMainTime() <= System.currentTimeMillis()) {
            throw new UEException("维保已过期，无法检查更新");
        }
        Map<String, Object> vmap = this.engineService.getUpgradeVersion("http://www.datacloudsec.com/upgrade/get-scan-last-ver.aj");
        if (vmap == null || vmap.size() == 0) {
            throw new UEException("当前版本已是最新版本");
        }
        List<Map<String, Object>> infos = (List) vmap.get("info");
        List<Map<String, Object>> result = new ArrayList<>();
        for (Map<String, Object> info : infos) {
            int type = ObjectUtil.getInt(info.get("type")).intValue();
            List<Map<String, Object>> list = this.engineService.getEngineByType(Integer.valueOf(type));
            if (list != null && list.size() > 0) {
                Map<String, Object> engine = list.get(0);
                String newver = ObjectUtil.getString(info.get("version"), "").replaceAll("v|V", "");
                String currver = type == 0 ? Config.getInstance().getString("version", "") : ObjectUtil.getString(engine.get("version"), "").replaceAll("v|V", "");
                if (!"".equals(newver) && VersionUtil.isNewVersion(currver, newver)) {
                    info.put("currver", currver);
                    info.put("size", ObjectUtil.sizeToStr(ObjectUtil.getLong(info.get("size"), 0L).longValue()));
                    info.put("desct", ObjectUtil.getString(info.get("desct"), "").replace("\n", "|"));
                    result.add(info);
                }
            }
        }
        if (result == null || result.size() == 0) {
            throw new UEException("当前版本已是最新版本");
        }
        return result;
    }

    public void offlineUpgrade(String upd) throws Exception {
        if (StringUtils.isBlank(upd)) {
            throw new UEException("参数错误");
        }
        List<Map<String, Object>> updList = (List) JsonUtil.MAPPER.readValue(upd, List.class);
        Collections.sort(updList, new Comparator<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.SystemService.3
            @Override // java.util.Comparator
            public int compare(Map<String, Object> a, Map<String, Object> b) {
                return ObjectUtil.getInt(a.get("type")).compareTo(ObjectUtil.getInt(b.get("type")));
            }
        });
        for (Map<String, Object> updMap : updList) {
            String path = ObjectUtil.getString(updMap.get("path"), "");
            String version = ObjectUtil.getString(updMap.get("version"), "");
            String currver = ObjectUtil.getString(updMap.get("currver"), "");
            Integer type = ObjectUtil.getInt(updMap.get("type"));
            File f = new File(path);
            try {
                try {
                    if (type.intValue() == 0) {
                        upgrade(f);
                    } else {
                        this.engineService.sendUpgrade(type, f);
                    }
                    if (f != null && f.exists()) {
                        f.delete();
                    }
                    this.engineMapper.addUpgrade(0, type, currver, version, ObjectUtil.getString(updMap.get("content"), ""), ObjectUtil.getString(updMap.get("policyList"), ""));
                } catch (Exception e) {
                    LOG.error("", e);
                    throw e;
                }
            } catch (Throwable th) {
                if (f != null && f.exists()) {
                    f.delete();
                }
                this.engineMapper.addUpgrade(0, type, currver, version, ObjectUtil.getString(updMap.get("content"), ""), ObjectUtil.getString(updMap.get("policyList"), ""));
                throw th;
            }
        }
        System.exit(0);
    }

    public void delUpgrade(Integer id) throws Exception {
        this.engineMapper.delUpgrade(id);
    }

    public List<Map<String, Object>> queryUpgrade() {
        return this.engineMapper.queryUpgrade();
    }

    public int getDiskUsed() throws Exception {
        String diskResult = RuntimeUtil.execShell("df -l|tail -n +2", "/dev/mapper/centos-root  49746196 6183792  43562404  13% /\r\ndevtmpfs                   929064       0    929064   0% /dev\r\ntmpfs                      941304       0    941304   0% /dev/shm\r\ntmpfs                      941304   91400    849904  10% /run\r\ntmpfs                      941304       0    941304   0% /sys/fs/cgroup\r\n/dev/sda1                  508588  168772    339816  34% /boot\r\ntmpfs                      188264       0    188264   0% /run/user/0");
        String[] lines = diskResult.replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n").split("\n");
        double total = 0.0d;
        int num = 0;
        for (String line : lines) {
            String[] entry = line.replaceAll("[\\s]{2,}", " ").split(" ");
            if (!entry[0].contains("/dev/cdrom") && !entry[0].contains("/dev/sr")) {
                num++;
                total += ObjectUtil.getDouble(entry[4].replace("%", ""), 0.0d);
            }
        }
        return (int) (total / num);
    }

    public int getMemUsed() throws Exception {
        String memResult = RuntimeUtil.execShell("free -m |grep Mem", "Mem:           1838        1110          69          88         658         483");
        String[] memCols = memResult.replaceAll("[\\s]{2,}", " ").split(" ");
        return (int) ((ObjectUtil.getDouble(memCols[2], 0.0d) / ObjectUtil.getDouble(memCols[1], 0.0d)) * 100.0d);
    }

    public int getCpuUsed() throws Exception {
        String cpuResult = RuntimeUtil.execShell("top -b -n 4 |grep %Cpu", "%Cpu(s):  6.7 us, 13.3 sy,  0.0 ni, 80.0 id,  0.0 wa,  0.0 hi,  0.0 si,  0.0 st\r\n%Cpu1  :  1.7 us,  3.0 sy,  0.0 ni, 95.3 id,  0.0 wa,  0.0 hi,  0.0 si,  0.0 st\r\n%Cpu2  :  1.4 us,  3.1 sy,  0.0 ni, 95.6 id,  0.0 wa,  0.0 hi,  0.0 si,  0.0 st\r\n%Cpu3  :  1.4 us,  2.7 sy,  0.0 ni, 95.9 id,  0.0 wa,  0.0 hi,  0.0 si,  0.0 st");
        String[] cpuLines = ObjectUtil.replaceNewline(cpuResult, "\n").split("\n");
        double totalCpu = 0.0d;
        for (int i = 1; i < cpuLines.length; i++) {
            String line = cpuLines[i];
            String[] cpuCols = line.split(",");
            totalCpu += 100.0d - ObjectUtil.getDouble(cpuCols[3].substring(0, cpuCols[3].lastIndexOf(" ")), 0.0d);
        }
        return (int) (totalCpu / (cpuLines.length - 1));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void upgrade(File updFile) throws Exception {
        File dir = ZipUtil.unZip(updFile, new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString()), "+_)(*&^%$#@!~asy");
        File content = new File(dir, "content");
        File afterSh = new File(dir, "shell/after.sh");
        File beforeSh = new File(dir, "shell/before.sh");
        File tomcatdir = ProjectUtil.getTomcatDir();
        if (beforeSh.isFile()) {
            RuntimeUtil.execShell("chmod +x " + beforeSh.getAbsolutePath());
            RuntimeUtil.execSh(beforeSh.getAbsolutePath());
        }
        if (content.isDirectory()) {
            File workdir = new File(content, "workdir");
            if (workdir.isDirectory()) {
                for (File f : workdir.listFiles()) {
                    if (f.isFile()) {
                        FileUtils.copyFileToDirectory(f, Constant.WORK_DIR);
                    } else if (f.isDirectory()) {
                        FileUtils.copyDirectoryToDirectory(f, Constant.WORK_DIR);
                    }
                }
            }
            File tomcat = new File(content, "tomcat");
            if (tomcat.isDirectory()) {
                for (File f2 : tomcat.listFiles()) {
                    if (f2.isFile()) {
                        FileUtils.copyFileToDirectory(f2, tomcatdir);
                    } else if (f2.isDirectory()) {
                        FileUtils.copyDirectoryToDirectory(f2, tomcatdir);
                    }
                }
            }
        }
        if (afterSh.isFile()) {
            RuntimeUtil.execShell("chmod +x " + afterSh.getAbsolutePath());
            RuntimeUtil.execSh(afterSh.getAbsolutePath());
        }
        FileUtils.deleteDirectory(dir);
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [com.datacloudsec.scan.service.impl.SystemService$4] */
    public void upgradePt(final File f) throws Exception {
        new Thread() { // from class: com.datacloudsec.scan.service.impl.SystemService.4
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                try {
                    Thread.sleep(3000L);
                    SystemService.this.upgrade(f);
                    System.exit(0);
                } catch (Exception e) {
                    SystemService.LOG.error("", e);
                }
            }
        }.start();
    }

    public static void main(String[] args) throws Exception {
        ISystem sys = new SystemService();
        System.out.println(sys.getCpuUsed());
        System.out.println(sys.getMemUsed());
        System.out.println(sys.getDiskUsed());
    }
}
